@@ -24,8 +24,8 @@ uiAnalyse <- function(csite, img_frmt, APP_RUN_MODE) {
               navbarMenu("More",
                   tabPanel("Well Report", fluid = TRUE, 
                            uiWellReport(csite, img_frmt) ),
-                  tabPanel("Plume Diagnostic", fluid = TRUE, 
-                           uiPlumeDiagnostics(csite, img_frmt) ),
+                  #tabPanel("Plume Diagnostic", fluid = TRUE, 
+                  #         uiPlumeDiagnostics(csite, img_frmt) ),
                   tabPanel("Spatiotemporal Predictions", fluid = TRUE, 
                            uiSTPredictions(csite, img_frmt) ),
                   "----",
